# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.query_lambda_sql import QueryLambdaSql  # noqa: F401,E501
from rockset.swagger_client.models.query_lambda_stats import QueryLambdaStats  # noqa: F401,E501


class QueryLambdaVersion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'workspace': 'str',
        'created_by': 'str',
        'created_at': 'str',
        'name': 'str',
        'version': 'str',
        'description': 'str',
        'sql': 'QueryLambdaSql',
        'collections': 'list[str]',
        'state': 'str',
        'stats': 'QueryLambdaStats'
    }

    attribute_map = {
        'workspace': 'workspace',
        'created_by': 'created_by',
        'created_at': 'created_at',
        'name': 'name',
        'version': 'version',
        'description': 'description',
        'sql': 'sql',
        'collections': 'collections',
        'state': 'state',
        'stats': 'stats'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """QueryLambdaVersion - a model defined in Swagger"""  # noqa: E501

        self._workspace = None
        self._created_by = None
        self._created_at = None
        self._name = None
        self._version = None
        self._description = None
        self._sql = None
        self._collections = None
        self._state = None
        self._stats = None
        self.discriminator = None

        self.workspace = kwargs.pop('workspace', None)
        self.created_by = kwargs.pop('created_by', None)
        self.created_at = kwargs.pop('created_at', None)
        self.name = kwargs.pop('name', None)
        self.version = kwargs.pop('version', None)
        self.description = kwargs.pop('description', None)
        self.sql = kwargs.pop('sql', None)
        self.collections = kwargs.pop('collections', None)
        self.state = kwargs.pop('state', None)
        self.stats = kwargs.pop('stats', None)

    @property
    def workspace(self):
        """Gets the workspace of this QueryLambdaVersion.  # noqa: E501

        workspace of this Query Lambda  # noqa: E501

        :return: The workspace of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this QueryLambdaVersion.

        workspace of this Query Lambda  # noqa: E501

        :param workspace: The workspace of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    @property
    def created_by(self):
        """Gets the created_by of this QueryLambdaVersion.  # noqa: E501

        user that created this Query Lambda  # noqa: E501

        :return: The created_by of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this QueryLambdaVersion.

        user that created this Query Lambda  # noqa: E501

        :param created_by: The created_by of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_at(self):
        """Gets the created_at of this QueryLambdaVersion.  # noqa: E501

        ISO-8601 date of when Query Lambda was created  # noqa: E501

        :return: The created_at of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this QueryLambdaVersion.

        ISO-8601 date of when Query Lambda was created  # noqa: E501

        :param created_at: The created_at of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def name(self):
        """Gets the name of this QueryLambdaVersion.  # noqa: E501

        Query Lambda name  # noqa: E501

        :return: The name of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this QueryLambdaVersion.

        Query Lambda name  # noqa: E501

        :param name: The name of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this QueryLambdaVersion.  # noqa: E501

        Query Lambda version  # noqa: E501

        :return: The version of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this QueryLambdaVersion.

        Query Lambda version  # noqa: E501

        :param version: The version of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def description(self):
        """Gets the description of this QueryLambdaVersion.  # noqa: E501

        optional description  # noqa: E501

        :return: The description of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryLambdaVersion.

        optional description  # noqa: E501

        :param description: The description of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def sql(self):
        """Gets the sql of this QueryLambdaVersion.  # noqa: E501

        Query Lambda SQL query  # noqa: E501

        :return: The sql of this QueryLambdaVersion.  # noqa: E501
        :rtype: QueryLambdaSql
        """
        return self._sql

    @sql.setter
    def sql(self, sql):
        """Sets the sql of this QueryLambdaVersion.

        Query Lambda SQL query  # noqa: E501

        :param sql: The sql of this QueryLambdaVersion.  # noqa: E501
        :type: QueryLambdaSql
        """

        self._sql = sql

    @property
    def collections(self):
        """Gets the collections of this QueryLambdaVersion.  # noqa: E501

        collections queried by underlying SQL query  # noqa: E501

        :return: The collections of this QueryLambdaVersion.  # noqa: E501
        :rtype: list[str]
        """
        return self._collections

    @collections.setter
    def collections(self, collections):
        """Sets the collections of this QueryLambdaVersion.

        collections queried by underlying SQL query  # noqa: E501

        :param collections: The collections of this QueryLambdaVersion.  # noqa: E501
        :type: list[str]
        """

        self._collections = collections

    @property
    def state(self):
        """Gets the state of this QueryLambdaVersion.  # noqa: E501

        status of this Query Lambda  # noqa: E501

        :return: The state of this QueryLambdaVersion.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this QueryLambdaVersion.

        status of this Query Lambda  # noqa: E501

        :param state: The state of this QueryLambdaVersion.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def stats(self):
        """Gets the stats of this QueryLambdaVersion.  # noqa: E501

        stats related to this Query Lambda  # noqa: E501

        :return: The stats of this QueryLambdaVersion.  # noqa: E501
        :rtype: QueryLambdaStats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this QueryLambdaVersion.

        stats related to this Query Lambda  # noqa: E501

        :param stats: The stats of this QueryLambdaVersion.  # noqa: E501
        :type: QueryLambdaStats
        """

        self._stats = stats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryLambdaVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryLambdaVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.pagination import Pagination  # noqa: F401,E501
from rockset.swagger_client.models.query_error import QueryError  # noqa: F401,E501
from rockset.swagger_client.models.stats import Stats  # noqa: F401,E501


class QueryInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_id': 'str',
        'status': 'str',
        'executed_by': 'str',
        'submitted_at': 'str',
        'expires_at': 'str',
        'stats': 'Stats',
        'pagination': 'Pagination',
        'last_offset': 'str',
        'query_errors': 'list[QueryError]'
    }

    attribute_map = {
        'query_id': 'query_id',
        'status': 'status',
        'executed_by': 'executed_by',
        'submitted_at': 'submitted_at',
        'expires_at': 'expires_at',
        'stats': 'stats',
        'pagination': 'pagination',
        'last_offset': 'last_offset',
        'query_errors': 'query_errors'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """QueryInfo - a model defined in Swagger"""  # noqa: E501

        self._query_id = None
        self._status = None
        self._executed_by = None
        self._submitted_at = None
        self._expires_at = None
        self._stats = None
        self._pagination = None
        self._last_offset = None
        self._query_errors = None
        self.discriminator = None

        self.query_id = kwargs.pop('query_id', None)
        self.status = kwargs.pop('status', None)
        self.executed_by = kwargs.pop('executed_by', None)
        self.submitted_at = kwargs.pop('submitted_at', None)
        self.expires_at = kwargs.pop('expires_at', None)
        self.stats = kwargs.pop('stats', None)
        self.pagination = kwargs.pop('pagination', None)
        self.last_offset = kwargs.pop('last_offset', None)
        self.query_errors = kwargs.pop('query_errors', None)

    @property
    def query_id(self):
        """Gets the query_id of this QueryInfo.  # noqa: E501

        Unique Query ID.  # noqa: E501

        :return: The query_id of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._query_id

    @query_id.setter
    def query_id(self, query_id):
        """Sets the query_id of this QueryInfo.

        Unique Query ID.  # noqa: E501

        :param query_id: The query_id of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._query_id = query_id

    @property
    def status(self):
        """Gets the status of this QueryInfo.  # noqa: E501

        Status of the query.  # noqa: E501

        :return: The status of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this QueryInfo.

        Status of the query.  # noqa: E501

        :param status: The status of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def executed_by(self):
        """Gets the executed_by of this QueryInfo.  # noqa: E501

        User ID who executed the query  # noqa: E501

        :return: The executed_by of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._executed_by

    @executed_by.setter
    def executed_by(self, executed_by):
        """Sets the executed_by of this QueryInfo.

        User ID who executed the query  # noqa: E501

        :param executed_by: The executed_by of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._executed_by = executed_by

    @property
    def submitted_at(self):
        """Gets the submitted_at of this QueryInfo.  # noqa: E501

        Time (UTC) the query request was first received and queued for execution.  # noqa: E501

        :return: The submitted_at of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._submitted_at

    @submitted_at.setter
    def submitted_at(self, submitted_at):
        """Sets the submitted_at of this QueryInfo.

        Time (UTC) the query request was first received and queued for execution.  # noqa: E501

        :param submitted_at: The submitted_at of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._submitted_at = submitted_at

    @property
    def expires_at(self):
        """Gets the expires_at of this QueryInfo.  # noqa: E501

        Time (UTC) that query results expire. Only populated if `status` is `COMPLETE`.  # noqa: E501

        :return: The expires_at of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this QueryInfo.

        Time (UTC) that query results expire. Only populated if `status` is `COMPLETE`.  # noqa: E501

        :param expires_at: The expires_at of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._expires_at = expires_at

    @property
    def stats(self):
        """Gets the stats of this QueryInfo.  # noqa: E501

        Various stats about the query's execution.  # noqa: E501

        :return: The stats of this QueryInfo.  # noqa: E501
        :rtype: Stats
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Sets the stats of this QueryInfo.

        Various stats about the query's execution.  # noqa: E501

        :param stats: The stats of this QueryInfo.  # noqa: E501
        :type: Stats
        """

        self._stats = stats

    @property
    def pagination(self):
        """Gets the pagination of this QueryInfo.  # noqa: E501

        Information for fetching query results pages. Only populated if `status` is `COMPLETE`.  # noqa: E501

        :return: The pagination of this QueryInfo.  # noqa: E501
        :rtype: Pagination
        """
        return self._pagination

    @pagination.setter
    def pagination(self, pagination):
        """Sets the pagination of this QueryInfo.

        Information for fetching query results pages. Only populated if `status` is `COMPLETE`.  # noqa: E501

        :param pagination: The pagination of this QueryInfo.  # noqa: E501
        :type: Pagination
        """

        self._pagination = pagination

    @property
    def last_offset(self):
        """Gets the last_offset of this QueryInfo.  # noqa: E501

        The log offset that query results were written to in the destination collection. Only populated for INSERT INTO queries.  # noqa: E501

        :return: The last_offset of this QueryInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_offset

    @last_offset.setter
    def last_offset(self, last_offset):
        """Sets the last_offset of this QueryInfo.

        The log offset that query results were written to in the destination collection. Only populated for INSERT INTO queries.  # noqa: E501

        :param last_offset: The last_offset of this QueryInfo.  # noqa: E501
        :type: str
        """

        self._last_offset = last_offset

    @property
    def query_errors(self):
        """Gets the query_errors of this QueryInfo.  # noqa: E501

        Errors encountered while executing the query.  # noqa: E501

        :return: The query_errors of this QueryInfo.  # noqa: E501
        :rtype: list[QueryError]
        """
        return self._query_errors

    @query_errors.setter
    def query_errors(self, query_errors):
        """Sets the query_errors of this QueryInfo.

        Errors encountered while executing the query.  # noqa: E501

        :param query_errors: The query_errors of this QueryInfo.  # noqa: E501
        :type: list[QueryError]
        """

        self._query_errors = query_errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/document.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import value_pb2 as rockset_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16rockset/document.proto\x12\x07rockset\x1a\x13rockset/value.proto\"I\n\x08\x44ocument\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\nevent_time\x18\x01 \x01(\x03\x12\x1d\n\x05value\x18\x03 \x01(\x0b\x32\x0e.rockset.ValueB\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_DOCUMENT = DESCRIPTOR.message_types_by_name['Document']
Document = _reflection.GeneratedProtocolMessageType('Document', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENT,
  '__module__' : 'rockset.document_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Document)
  })
_sym_db.RegisterMessage(Document)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _DOCUMENT._serialized_start=56
  _DOCUMENT._serialized_end=129
# @@protoc_insertion_point(module_scope)



import unittest


def my_test_suite():
    test_loader = unittest.TestLoader()
    test_suite = unittest.TestSuite()
    test_suite.addTest(test_loader.discover("rockset.tests"))
    test_suite.addTest(test_loader.discover("rockset.sql.tests"))
    test_suite.addTest(test_loader.discover("rockset.rock.tests"))
    return test_suite



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Cluster(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'cluster_type': 'str',
        'aws_region': 'str',
        'domain': 'str',
        'top_level_domain': 'str',
        'apiserver_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'cluster_type': 'cluster_type',
        'aws_region': 'aws_region',
        'domain': 'domain',
        'top_level_domain': 'top_level_domain',
        'apiserver_url': 'apiserver_url'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """Cluster - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._cluster_type = None
        self._aws_region = None
        self._domain = None
        self._top_level_domain = None
        self._apiserver_url = None
        self.discriminator = None

        self.id = kwargs.pop('id', None)
        self.cluster_type = kwargs.pop('cluster_type', None)
        self.aws_region = kwargs.pop('aws_region', None)
        self.domain = kwargs.pop('domain', None)
        self.top_level_domain = kwargs.pop('top_level_domain', None)
        self.apiserver_url = kwargs.pop('apiserver_url', None)

    @property
    def id(self):
        """Gets the id of this Cluster.  # noqa: E501

        unique identifier for the cluster  # noqa: E501

        :return: The id of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Cluster.

        unique identifier for the cluster  # noqa: E501

        :param id: The id of this Cluster.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def cluster_type(self):
        """Gets the cluster_type of this Cluster.  # noqa: E501

        cluster type  # noqa: E501

        :return: The cluster_type of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._cluster_type

    @cluster_type.setter
    def cluster_type(self, cluster_type):
        """Sets the cluster_type of this Cluster.

        cluster type  # noqa: E501

        :param cluster_type: The cluster_type of this Cluster.  # noqa: E501
        :type: str
        """

        self._cluster_type = cluster_type

    @property
    def aws_region(self):
        """Gets the aws_region of this Cluster.  # noqa: E501

        aws region  # noqa: E501

        :return: The aws_region of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._aws_region

    @aws_region.setter
    def aws_region(self, aws_region):
        """Sets the aws_region of this Cluster.

        aws region  # noqa: E501

        :param aws_region: The aws_region of this Cluster.  # noqa: E501
        :type: str
        """

        self._aws_region = aws_region

    @property
    def domain(self):
        """Gets the domain of this Cluster.  # noqa: E501

        domain of org using cluster  # noqa: E501

        :return: The domain of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this Cluster.

        domain of org using cluster  # noqa: E501

        :param domain: The domain of this Cluster.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def top_level_domain(self):
        """Gets the top_level_domain of this Cluster.  # noqa: E501

        top level domain of org using cluster  # noqa: E501

        :return: The top_level_domain of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._top_level_domain

    @top_level_domain.setter
    def top_level_domain(self, top_level_domain):
        """Sets the top_level_domain of this Cluster.

        top level domain of org using cluster  # noqa: E501

        :param top_level_domain: The top_level_domain of this Cluster.  # noqa: E501
        :type: str
        """

        self._top_level_domain = top_level_domain

    @property
    def apiserver_url(self):
        """Gets the apiserver_url of this Cluster.  # noqa: E501

        api server url for cluster  # noqa: E501

        :return: The apiserver_url of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._apiserver_url

    @apiserver_url.setter
    def apiserver_url(self, apiserver_url):
        """Sets the apiserver_url of this Cluster.

        api server url for cluster  # noqa: E501

        :param apiserver_url: The apiserver_url of this Cluster.  # noqa: E501
        :type: str
        """

        self._apiserver_url = apiserver_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Cluster, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cluster):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/query_field_path.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1erockset/query_field_path.proto\x12\x07rockset\"\x1a\n\x18\x41llIndexesQueryFieldPath\"\xb1\x01\n\x17QueryFieldPathComponent\x12\x0f\n\x05index\x18\x01 \x01(\x05H\x00\x12\r\n\x03key\x18\x02 \x01(\tH\x00\x12\x38\n\x0b\x61ll_indexes\x18\x03 \x01(\x0b\x32!.rockset.AllIndexesQueryFieldPathH\x00\x12.\n\rspecial_field\x18\x04 \x01(\x0e\x32\x15.rockset.SpecialFieldH\x00\x42\x0c\n\npath_union\"F\n\x0eQueryFieldPath\x12\x34\n\ncomponents\x18\x01 \x03(\x0b\x32 .rockset.QueryFieldPathComponent* \n\x0cSpecialField\x12\x10\n\x0cSFIELD_SCORE\x10\x00\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3')

_SPECIALFIELD = DESCRIPTOR.enum_types_by_name['SpecialField']
SpecialField = enum_type_wrapper.EnumTypeWrapper(_SPECIALFIELD)
SFIELD_SCORE = 0


_ALLINDEXESQUERYFIELDPATH = DESCRIPTOR.message_types_by_name['AllIndexesQueryFieldPath']
_QUERYFIELDPATHCOMPONENT = DESCRIPTOR.message_types_by_name['QueryFieldPathComponent']
_QUERYFIELDPATH = DESCRIPTOR.message_types_by_name['QueryFieldPath']
AllIndexesQueryFieldPath = _reflection.GeneratedProtocolMessageType('AllIndexesQueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _ALLINDEXESQUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.AllIndexesQueryFieldPath)
  })
_sym_db.RegisterMessage(AllIndexesQueryFieldPath)

QueryFieldPathComponent = _reflection.GeneratedProtocolMessageType('QueryFieldPathComponent', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATHCOMPONENT,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPathComponent)
  })
_sym_db.RegisterMessage(QueryFieldPathComponent)

QueryFieldPath = _reflection.GeneratedProtocolMessageType('QueryFieldPath', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFIELDPATH,
  '__module__' : 'rockset.query_field_path_pb2'
  # @@protoc_insertion_point(class_scope:rockset.QueryFieldPath)
  })
_sym_db.RegisterMessage(QueryFieldPath)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000'
  _SPECIALFIELD._serialized_start=323
  _SPECIALFIELD._serialized_end=355
  _ALLINDEXESQUERYFIELDPATH._serialized_start=43
  _ALLINDEXESQUERYFIELDPATH._serialized_end=69
  _QUERYFIELDPATHCOMPONENT._serialized_start=72
  _QUERYFIELDPATHCOMPONENT._serialized_end=249
  _QUERYFIELDPATH._serialized_start=251
  _QUERYFIELDPATH._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/regex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13rockset/regex.proto\x12\x07rockset\"e\n\x05Regex\x12\x0f\n\x07pattern\x18\x01 \x01(\t\x12)\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x17.rockset.Regex.Encoding\" \n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\n\n\x06LATIN1\x10\x01\x42\x14\n\x10io.rockset.protoP\x00\x62\x06proto3')



_REGEX = DESCRIPTOR.message_types_by_name['Regex']
_REGEX_ENCODING = _REGEX.enum_types_by_name['Encoding']
Regex = _reflection.GeneratedProtocolMessageType('Regex', (_message.Message,), {
  'DESCRIPTOR' : _REGEX,
  '__module__' : 'rockset.regex_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Regex)
  })
_sym_db.RegisterMessage(Regex)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000'
  _REGEX._serialized_start=32
  _REGEX._serialized_end=133
  _REGEX_ENCODING._serialized_start=101
  _REGEX_ENCODING._serialized_end=133
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/document_locator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1erockset/document_locator.proto\"J\n\x14\x44ocumentLocatorProto\x12\x0e\n\x06raw_id\x18\x01 \x01(\x04\x12\x0f\n\x07indices\x18\x02 \x03(\r\x12\x11\n\tpartition\x18\x03 \x01(\x03\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_DOCUMENTLOCATORPROTO = DESCRIPTOR.message_types_by_name['DocumentLocatorProto']
DocumentLocatorProto = _reflection.GeneratedProtocolMessageType('DocumentLocatorProto', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTLOCATORPROTO,
  '__module__' : 'rockset.document_locator_pb2'
  # @@protoc_insertion_point(class_scope:DocumentLocatorProto)
  })
_sym_db.RegisterMessage(DocumentLocatorProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _DOCUMENTLOCATORPROTO._serialized_start=34
  _DOCUMENTLOCATORPROTO._serialized_end=108
# @@protoc_insertion_point(module_scope)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.status_azure_event_hubs_partition import StatusAzureEventHubsPartition  # noqa: F401,E501


class StatusAzureEventHubs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'state': 'str',
        'last_consumed_time': 'str',
        'num_documents_processed': 'int',
        'partitions': 'list[StatusAzureEventHubsPartition]'
    }

    attribute_map = {
        'state': 'state',
        'last_consumed_time': 'last_consumed_time',
        'num_documents_processed': 'num_documents_processed',
        'partitions': 'partitions'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """StatusAzureEventHubs - a model defined in Swagger"""  # noqa: E501

        self._state = None
        self._last_consumed_time = None
        self._num_documents_processed = None
        self._partitions = None
        self.discriminator = None

        self.state = kwargs.pop('state', None)
        self.last_consumed_time = kwargs.pop('last_consumed_time', None)
        self.num_documents_processed = kwargs.pop('num_documents_processed', None)
        self.partitions = kwargs.pop('partitions', None)

    @property
    def state(self):
        """Gets the state of this StatusAzureEventHubs.  # noqa: E501

        State of the source  # noqa: E501

        :return: The state of this StatusAzureEventHubs.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this StatusAzureEventHubs.

        State of the source  # noqa: E501

        :param state: The state of this StatusAzureEventHubs.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def last_consumed_time(self):
        """Gets the last_consumed_time of this StatusAzureEventHubs.  # noqa: E501

        Time at which the last document was consumed  # noqa: E501

        :return: The last_consumed_time of this StatusAzureEventHubs.  # noqa: E501
        :rtype: str
        """
        return self._last_consumed_time

    @last_consumed_time.setter
    def last_consumed_time(self, last_consumed_time):
        """Sets the last_consumed_time of this StatusAzureEventHubs.

        Time at which the last document was consumed  # noqa: E501

        :param last_consumed_time: The last_consumed_time of this StatusAzureEventHubs.  # noqa: E501
        :type: str
        """

        self._last_consumed_time = last_consumed_time

    @property
    def num_documents_processed(self):
        """Gets the num_documents_processed of this StatusAzureEventHubs.  # noqa: E501

        Number of documents consumed  # noqa: E501

        :return: The num_documents_processed of this StatusAzureEventHubs.  # noqa: E501
        :rtype: int
        """
        return self._num_documents_processed

    @num_documents_processed.setter
    def num_documents_processed(self, num_documents_processed):
        """Sets the num_documents_processed of this StatusAzureEventHubs.

        Number of documents consumed  # noqa: E501

        :param num_documents_processed: The num_documents_processed of this StatusAzureEventHubs.  # noqa: E501
        :type: int
        """

        self._num_documents_processed = num_documents_processed

    @property
    def partitions(self):
        """Gets the partitions of this StatusAzureEventHubs.  # noqa: E501

        Status info per partition  # noqa: E501

        :return: The partitions of this StatusAzureEventHubs.  # noqa: E501
        :rtype: list[StatusAzureEventHubsPartition]
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this StatusAzureEventHubs.

        Status info per partition  # noqa: E501

        :param partitions: The partitions of this StatusAzureEventHubs.  # noqa: E501
        :type: list[StatusAzureEventHubsPartition]
        """

        self._partitions = partitions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusAzureEventHubs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusAzureEventHubs):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



#!/usr/bin/env python3

import sys
import traceback
import json
import unittest
from setuptools import setup
from setuptools import find_packages


def get_version():
    version = {}
    with open("rockset/version.json", "r") as vf:
        version = json.load(vf)
    return version


def get_long_description():
    with open("DESCRIPTION_sqlcli.rst", encoding="utf-8") as fd:
        long_description = fd.read()
    long_description += "\n"
    with open("RELEASE.rst", encoding="utf-8") as fd:
        long_description += fd.read()
    return long_description


# TODO: Add tests for rock-sql
setup(
    name="rockset_sqlcli",
    version=get_version().get("python", "???"),
    description="Rockset SQL REPL for `rock sql`",
    long_description=get_long_description(),
    author="Rockset, Inc",
    author_email="api@rockset.io",
    url="https://rockset.com",
    keywords="Rockset serverless search and analytics",
    packages=find_packages(
        include=[
            "rockset_sqlcli",
            "rockset_sqlcli.*",
        ],
    ),
    install_requires=[
        "cli_helpers[styles] >= 1.0.1",
        "click >= 4.1",
        "configobj >= 5.0.6",
        "humanize >= 0.5.1",
        "prompt_toolkit == 1.0.13",
        "Pygments >= 2.0",
        "pyyaml >= 3.11",
        "rockset >= 0.6.0b20190617 ",
        "sqlparse >= 0.2.2",
        "webcolors >= 1.7",
    ],
    entry_points={
        "console_scripts": [
            "rock-sql = rockset_sqlcli.main:main",
        ],
    },
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Science/Research",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: SQL",
        "Topic :: Database",
        "Topic :: Database :: Database Engines/Servers",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Shells",
        "Topic :: Internet :: WWW/HTTP :: Indexing/Search",
    ],
    package_data={
        "rockset_sqlcli": [
            "README.rst",
            "pgcli-AUTHORS",
            "pgcli-LICENSE.txt",
            "rscli/rsclirc",
            "rscli/packages/rsliterals/rsliterals.json",
        ],
    },
)



from rockset import Client
from .command_rest import RESTCommand

from docopt import docopt

import json
import os
import sys
import yaml


class SetState(RESTCommand):
    def usage(self):
        return """
usage: rock setstate --help
       rock setstate <collection> <state>

Set the state of a collection to either READY or PAUSED

arguments for `rock setstate`:
  <collection>      name of the collection you wish to add data
  <state>           "READY" or "PAUSED"

options for `rock setstate`:
  -h, --help                show this help message and exit

examples:

    Set the state of a collection to READY:
        $ rock setstate my-collection READY

    Set the state of a collection to PAUSED
        $ rock setstate my-collection PAUSED

        """

    def parse_args(self, args):
        parsed_args = dict(docopt(self.usage(), argv=args, help=False))
        if parsed_args["--help"]:
            ret = self.usage()
            raise SystemExit(ret.strip())

        params = {}

        if parsed_args["<collection>"]:
            params["collection"] = parsed_args["<collection>"]

        if parsed_args["<state>"]:
            params["state"] = parsed_args["<state>"].upper()
        print(params)

        return {"params": params}

    def go(self):
        path = "/v1/orgs/{}/ws/{}/collections/{}/state/{}".format(
            "self", "commons", self.params["collection"], self.params["state"]
        )

        deets = self.post(path)
        if "sources" in deets:
            nsrcs = []
            for src in deets["sources"]:
                nsrcs.append({k: v for k, v in src.items() if v})
            deets["data"]["sources"] = nsrcs
        desc = {}
        if "data" in deets:
            desc = {k: v for k, v in deets["data"].items() if v}
        self.print_list_yaml(0, [desc])
        return 0



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rockset/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rockset import document_locator_pb2 as rockset_dot_document__locator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13rockset/value.proto\x12\x07rockset\x1a\x1erockset/document_locator.proto\"\x07\n\x05\x45mpty\"5\n\tDateProto\x12\x0c\n\x04year\x18\x01 \x01(\x03\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"N\n\tTimeProto\x12\x0c\n\x04hour\x18\x01 \x01(\x05\x12\x0e\n\x06minute\x18\x02 \x01(\x05\x12\x0e\n\x06second\x18\x03 \x01(\x05\x12\x13\n\x0bmicrosecond\x18\x04 \x01(\x05\"S\n\rDateTimeProto\x12 \n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x12.rockset.DateProto\x12 \n\x04time\x18\x02 \x01(\x0b\x32\x12.rockset.TimeProto\":\n\x13GeographyPointProto\x12\x11\n\tlongitude\x18\x01 \x01(\x01\x12\x10\n\x08latitude\x18\x02 \x01(\x01\"H\n\x18GeographyLineStringProto\x12,\n\x06points\x18\x01 \x03(\x0b\x32\x1c.rockset.GeographyPointProto\"I\n\x15GeographyPolygonProto\x12\x30\n\x05loops\x18\x01 \x03(\x0b\x32!.rockset.GeographyLineStringProto\"1\n\x1bGeographyRangeEndpointProto\x12\x12\n\nindex_term\x18\x01 \x01(\t\"\xff\x01\n\x0eGeographyProto\x12-\n\x05point\x18\x01 \x01(\x0b\x32\x1c.rockset.GeographyPointProtoH\x00\x12\x38\n\x0bline_string\x18\x02 \x01(\x0b\x32!.rockset.GeographyLineStringProtoH\x00\x12\x31\n\x07polygon\x18\x03 \x01(\x0b\x32\x1e.rockset.GeographyPolygonProtoH\x00\x12>\n\x0erange_endpoint\x18\x04 \x01(\x0b\x32$.rockset.GeographyRangeEndpointProtoH\x00\x42\x11\n\x0fgeography_union\"%\n\x0bInt128Proto\x12\n\n\x02hi\x18\x01 \x01(\x04\x12\n\n\x02lo\x18\x02 \x01(\x04\"\x86\x0b\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x03 \x01(\x08H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12,\n\x0cobject_value\x18\x06 \x01(\x0b\x32\x14.rockset.ObjectValueH\x00\x12*\n\x0b\x61rray_value\x18\x07 \x01(\x0b\x32\x13.rockset.ArrayValueH\x00\x12,\n\x0c\x63ustom_value\x18\x08 \x01(\x0b\x32\x14.rockset.CustomValueH\x00\x12\x14\n\nnull_value\x18\t \x01(\x08H\x00\x12.\n\rlocator_value\x18\n \x01(\x0b\x32\x15.DocumentLocatorProtoH\x00\x12\x19\n\x0ftimestamp_value\x18\x0b \x01(\x03H\x00\x12\x30\n\x0e\x64\x61tetime_value\x18\x0c \x01(\x0b\x32\x16.rockset.DateTimeProtoH\x00\x12(\n\ndate_value\x18\r \x01(\x0b\x32\x12.rockset.DateProtoH\x00\x12(\n\ntime_value\x18\x0e \x01(\x0b\x32\x12.rockset.TimeProtoH\x00\x12\x1e\n\x14month_interval_value\x18\x0f \x01(\x03H\x00\x12$\n\x1amicrosecond_interval_value\x18\x10 \x01(\x03H\x00\x12\x17\n\runknown_value\x18\x11 \x01(\x08H\x00\x12\x32\n\x0fgeography_value\x18\x12 \x01(\x0b\x32\x17.rockset.GeographyProtoH\x00\x12\x31\n\x0fint_array_value\x18\x13 \x01(\x0b\x32\x16.rockset.IntArrayValueH\x00\x12\x35\n\x11\x66loat_array_value\x18\x14 \x01(\x0b\x32\x18.rockset.FloatArrayValueH\x00\x12\x33\n\x10\x62ool_array_value\x18\x15 \x01(\x0b\x32\x17.rockset.BoolArrayValueH\x00\x12\x37\n\x12string_array_value\x18\x16 \x01(\x0b\x32\x19.rockset.StringArrayValueH\x00\x12\x39\n\x13locator_array_value\x18\x17 \x01(\x0b\x32\x1a.rockset.LocatorArrayValueH\x00\x12=\n\x15timestamp_array_value\x18\x18 \x01(\x0b\x32\x1c.rockset.TimestampArrayValueH\x00\x12<\n\x15\x64\x61te_time_array_value\x18\x19 \x01(\x0b\x32\x1b.rockset.DateTimeArrayValueH\x00\x12\x33\n\x10\x64\x61te_array_value\x18\x1a \x01(\x0b\x32\x17.rockset.DateArrayValueH\x00\x12\x33\n\x10time_array_value\x18\x1b \x01(\x0b\x32\x17.rockset.TimeArrayValueH\x00\x12\x46\n\x1amonth_interval_array_value\x18\x1c \x01(\x0b\x32 .rockset.MonthIntervalArrayValueH\x00\x12R\n microsecond_interval_array_value\x18\x1d \x01(\x0b\x32&.rockset.MicrosecondIntervalArrayValueH\x00\x12,\n\x0cint128_value\x18\x1e \x01(\x0b\x32\x14.rockset.Int128ProtoH\x00\x12\x37\n\x12int128_array_value\x18\x1f \x01(\x0b\x32\x19.rockset.Int128ArrayValueH\x00\x42\r\n\x0bvalue_union\",\n\x0b\x43ustomValue\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07\x65ncoded\x18\x02 \x01(\x0c\"3\n\x05\x46ield\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.rockset.Value\"-\n\x0bObjectValue\x12\x1e\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x0e.rockset.Field\"+\n\nArrayValue\x12\x1d\n\x05value\x18\x02 \x03(\x0b\x32\x0e.rockset.Value\"\x1d\n\nNullsValue\x12\x0f\n\x07storage\x18\x01 \x03(\x04\"B\n\rIntArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"D\n\x0f\x46loatArrayValue\x12\r\n\x05value\x18\x01 \x03(\x01\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"C\n\x0e\x42oolArrayValue\x12\r\n\x05value\x18\x01 \x03(\x08\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"<\n\x1aStringArrayValueDictionary\x12\x0f\n\x07offsets\x18\x01 \x03(\r\x12\r\n\x05words\x18\x02 \x01(\x0c\"~\n\x10StringArrayValue\x12\r\n\x05value\x18\x01 \x03(\r\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\x12\x37\n\ndictionary\x18\x03 \x01(\x0b\x32#.rockset.StringArrayValueDictionary\"]\n\x11LocatorArrayValue\x12$\n\x05value\x18\x01 \x03(\x0b\x32\x15.DocumentLocatorProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"H\n\x13TimestampArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"_\n\x12\x44\x61teTimeArrayValue\x12%\n\x05value\x18\x01 \x03(\x0b\x32\x16.rockset.DateTimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0e\x44\x61teArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.DateProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"W\n\x0eTimeArrayValue\x12!\n\x05value\x18\x01 \x03(\x0b\x32\x12.rockset.TimeProto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"L\n\x17MonthIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"R\n\x1dMicrosecondIntervalArrayValue\x12\r\n\x05value\x18\x01 \x03(\x03\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"[\n\x10Int128ArrayValue\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.rockset.Int128Proto\x12\"\n\x05nulls\x18\x02 \x01(\x0b\x32\x13.rockset.NullsValue\"\x8c\x03\n\x04Type\x12(\n\x04type\x18\x01 \x01(\x0e\x32\x18.rockset.Type.ScalarTypeH\x00\x12*\n\x0bobject_type\x18\x02 \x01(\x0b\x32\x13.rockset.ObjectTypeH\x00\x12(\n\narray_type\x18\x03 \x01(\x0b\x32\x12.rockset.ArrayTypeH\x00\x12*\n\x0b\x63ustom_type\x18\x04 \x01(\x0b\x32\x13.rockset.CustomTypeH\x00\x12\x10\n\x08inferred\x18\x05 \x01(\x08\x12%\n\rdefault_value\x18\x06 \x01(\x0b\x32\x0e.rockset.Value\x12#\n\x0csource_field\x18\x07 \x01(\x0b\x32\r.rockset.Type\x12\x0e\n\x06stored\x18\x08 \x01(\x08\x12\x0f\n\x07indexed\x18\t \x01(\x08\"K\n\nScalarType\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03INT\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\n\n\x06STRING\x10\x04\x12\t\n\x05\x42YTES\x10\x05\x42\x0c\n\ntype_union\"3\n\x07KeyType\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x04type\x18\x02 \x01(\x0b\x32\r.rockset.Type\"*\n\nObjectType\x12\x1c\n\x02kt\x18\x01 \x03(\x0b\x32\x10.rockset.KeyType\"(\n\tArrayType\x12\x1b\n\x04type\x18\x01 \x01(\x0b\x32\r.rockset.Type\"\x1a\n\nCustomType\x12\x0c\n\x04type\x18\x01 \x01(\r\"\x1d\n\x0b\x42itSetProto\x12\x0e\n\x06\x62locks\x18\x01 \x03(\x07\x42\x17\n\x10io.rockset.protoP\x00\xf8\x01\x01\x62\x06proto3')



_EMPTY = DESCRIPTOR.message_types_by_name['Empty']
_DATEPROTO = DESCRIPTOR.message_types_by_name['DateProto']
_TIMEPROTO = DESCRIPTOR.message_types_by_name['TimeProto']
_DATETIMEPROTO = DESCRIPTOR.message_types_by_name['DateTimeProto']
_GEOGRAPHYPOINTPROTO = DESCRIPTOR.message_types_by_name['GeographyPointProto']
_GEOGRAPHYLINESTRINGPROTO = DESCRIPTOR.message_types_by_name['GeographyLineStringProto']
_GEOGRAPHYPOLYGONPROTO = DESCRIPTOR.message_types_by_name['GeographyPolygonProto']
_GEOGRAPHYRANGEENDPOINTPROTO = DESCRIPTOR.message_types_by_name['GeographyRangeEndpointProto']
_GEOGRAPHYPROTO = DESCRIPTOR.message_types_by_name['GeographyProto']
_INT128PROTO = DESCRIPTOR.message_types_by_name['Int128Proto']
_VALUE = DESCRIPTOR.message_types_by_name['Value']
_CUSTOMVALUE = DESCRIPTOR.message_types_by_name['CustomValue']
_FIELD = DESCRIPTOR.message_types_by_name['Field']
_OBJECTVALUE = DESCRIPTOR.message_types_by_name['ObjectValue']
_ARRAYVALUE = DESCRIPTOR.message_types_by_name['ArrayValue']
_NULLSVALUE = DESCRIPTOR.message_types_by_name['NullsValue']
_INTARRAYVALUE = DESCRIPTOR.message_types_by_name['IntArrayValue']
_FLOATARRAYVALUE = DESCRIPTOR.message_types_by_name['FloatArrayValue']
_BOOLARRAYVALUE = DESCRIPTOR.message_types_by_name['BoolArrayValue']
_STRINGARRAYVALUEDICTIONARY = DESCRIPTOR.message_types_by_name['StringArrayValueDictionary']
_STRINGARRAYVALUE = DESCRIPTOR.message_types_by_name['StringArrayValue']
_LOCATORARRAYVALUE = DESCRIPTOR.message_types_by_name['LocatorArrayValue']
_TIMESTAMPARRAYVALUE = DESCRIPTOR.message_types_by_name['TimestampArrayValue']
_DATETIMEARRAYVALUE = DESCRIPTOR.message_types_by_name['DateTimeArrayValue']
_DATEARRAYVALUE = DESCRIPTOR.message_types_by_name['DateArrayValue']
_TIMEARRAYVALUE = DESCRIPTOR.message_types_by_name['TimeArrayValue']
_MONTHINTERVALARRAYVALUE = DESCRIPTOR.message_types_by_name['MonthIntervalArrayValue']
_MICROSECONDINTERVALARRAYVALUE = DESCRIPTOR.message_types_by_name['MicrosecondIntervalArrayValue']
_INT128ARRAYVALUE = DESCRIPTOR.message_types_by_name['Int128ArrayValue']
_TYPE = DESCRIPTOR.message_types_by_name['Type']
_KEYTYPE = DESCRIPTOR.message_types_by_name['KeyType']
_OBJECTTYPE = DESCRIPTOR.message_types_by_name['ObjectType']
_ARRAYTYPE = DESCRIPTOR.message_types_by_name['ArrayType']
_CUSTOMTYPE = DESCRIPTOR.message_types_by_name['CustomType']
_BITSETPROTO = DESCRIPTOR.message_types_by_name['BitSetProto']
_TYPE_SCALARTYPE = _TYPE.enum_types_by_name['ScalarType']
Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Empty)
  })
_sym_db.RegisterMessage(Empty)

DateProto = _reflection.GeneratedProtocolMessageType('DateProto', (_message.Message,), {
  'DESCRIPTOR' : _DATEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateProto)
  })
_sym_db.RegisterMessage(DateProto)

TimeProto = _reflection.GeneratedProtocolMessageType('TimeProto', (_message.Message,), {
  'DESCRIPTOR' : _TIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeProto)
  })
_sym_db.RegisterMessage(TimeProto)

DateTimeProto = _reflection.GeneratedProtocolMessageType('DateTimeProto', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeProto)
  })
_sym_db.RegisterMessage(DateTimeProto)

GeographyPointProto = _reflection.GeneratedProtocolMessageType('GeographyPointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPointProto)
  })
_sym_db.RegisterMessage(GeographyPointProto)

GeographyLineStringProto = _reflection.GeneratedProtocolMessageType('GeographyLineStringProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYLINESTRINGPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyLineStringProto)
  })
_sym_db.RegisterMessage(GeographyLineStringProto)

GeographyPolygonProto = _reflection.GeneratedProtocolMessageType('GeographyPolygonProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPOLYGONPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyPolygonProto)
  })
_sym_db.RegisterMessage(GeographyPolygonProto)

GeographyRangeEndpointProto = _reflection.GeneratedProtocolMessageType('GeographyRangeEndpointProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYRANGEENDPOINTPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyRangeEndpointProto)
  })
_sym_db.RegisterMessage(GeographyRangeEndpointProto)

GeographyProto = _reflection.GeneratedProtocolMessageType('GeographyProto', (_message.Message,), {
  'DESCRIPTOR' : _GEOGRAPHYPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.GeographyProto)
  })
_sym_db.RegisterMessage(GeographyProto)

Int128Proto = _reflection.GeneratedProtocolMessageType('Int128Proto', (_message.Message,), {
  'DESCRIPTOR' : _INT128PROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128Proto)
  })
_sym_db.RegisterMessage(Int128Proto)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Value)
  })
_sym_db.RegisterMessage(Value)

CustomValue = _reflection.GeneratedProtocolMessageType('CustomValue', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomValue)
  })
_sym_db.RegisterMessage(CustomValue)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
  'DESCRIPTOR' : _FIELD,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Field)
  })
_sym_db.RegisterMessage(Field)

ObjectValue = _reflection.GeneratedProtocolMessageType('ObjectValue', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectValue)
  })
_sym_db.RegisterMessage(ObjectValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)

NullsValue = _reflection.GeneratedProtocolMessageType('NullsValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLSVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.NullsValue)
  })
_sym_db.RegisterMessage(NullsValue)

IntArrayValue = _reflection.GeneratedProtocolMessageType('IntArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.IntArrayValue)
  })
_sym_db.RegisterMessage(IntArrayValue)

FloatArrayValue = _reflection.GeneratedProtocolMessageType('FloatArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _FLOATARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.FloatArrayValue)
  })
_sym_db.RegisterMessage(FloatArrayValue)

BoolArrayValue = _reflection.GeneratedProtocolMessageType('BoolArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BoolArrayValue)
  })
_sym_db.RegisterMessage(BoolArrayValue)

StringArrayValueDictionary = _reflection.GeneratedProtocolMessageType('StringArrayValueDictionary', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUEDICTIONARY,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValueDictionary)
  })
_sym_db.RegisterMessage(StringArrayValueDictionary)

StringArrayValue = _reflection.GeneratedProtocolMessageType('StringArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.StringArrayValue)
  })
_sym_db.RegisterMessage(StringArrayValue)

LocatorArrayValue = _reflection.GeneratedProtocolMessageType('LocatorArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _LOCATORARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.LocatorArrayValue)
  })
_sym_db.RegisterMessage(LocatorArrayValue)

TimestampArrayValue = _reflection.GeneratedProtocolMessageType('TimestampArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMPARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimestampArrayValue)
  })
_sym_db.RegisterMessage(TimestampArrayValue)

DateTimeArrayValue = _reflection.GeneratedProtocolMessageType('DateTimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATETIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateTimeArrayValue)
  })
_sym_db.RegisterMessage(DateTimeArrayValue)

DateArrayValue = _reflection.GeneratedProtocolMessageType('DateArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _DATEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.DateArrayValue)
  })
_sym_db.RegisterMessage(DateArrayValue)

TimeArrayValue = _reflection.GeneratedProtocolMessageType('TimeArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _TIMEARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.TimeArrayValue)
  })
_sym_db.RegisterMessage(TimeArrayValue)

MonthIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MonthIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MONTHINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MonthIntervalArrayValue)
  })
_sym_db.RegisterMessage(MonthIntervalArrayValue)

MicrosecondIntervalArrayValue = _reflection.GeneratedProtocolMessageType('MicrosecondIntervalArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _MICROSECONDINTERVALARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.MicrosecondIntervalArrayValue)
  })
_sym_db.RegisterMessage(MicrosecondIntervalArrayValue)

Int128ArrayValue = _reflection.GeneratedProtocolMessageType('Int128ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _INT128ARRAYVALUE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Int128ArrayValue)
  })
_sym_db.RegisterMessage(Int128ArrayValue)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
  'DESCRIPTOR' : _TYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.Type)
  })
_sym_db.RegisterMessage(Type)

KeyType = _reflection.GeneratedProtocolMessageType('KeyType', (_message.Message,), {
  'DESCRIPTOR' : _KEYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.KeyType)
  })
_sym_db.RegisterMessage(KeyType)

ObjectType = _reflection.GeneratedProtocolMessageType('ObjectType', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ObjectType)
  })
_sym_db.RegisterMessage(ObjectType)

ArrayType = _reflection.GeneratedProtocolMessageType('ArrayType', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.ArrayType)
  })
_sym_db.RegisterMessage(ArrayType)

CustomType = _reflection.GeneratedProtocolMessageType('CustomType', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTYPE,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.CustomType)
  })
_sym_db.RegisterMessage(CustomType)

BitSetProto = _reflection.GeneratedProtocolMessageType('BitSetProto', (_message.Message,), {
  'DESCRIPTOR' : _BITSETPROTO,
  '__module__' : 'rockset.value_pb2'
  # @@protoc_insertion_point(class_scope:rockset.BitSetProto)
  })
_sym_db.RegisterMessage(BitSetProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020io.rockset.protoP\000\370\001\001'
  _EMPTY._serialized_start=64
  _EMPTY._serialized_end=71
  _DATEPROTO._serialized_start=73
  _DATEPROTO._serialized_end=126
  _TIMEPROTO._serialized_start=128
  _TIMEPROTO._serialized_end=206
  _DATETIMEPROTO._serialized_start=208
  _DATETIMEPROTO._serialized_end=291
  _GEOGRAPHYPOINTPROTO._serialized_start=293
  _GEOGRAPHYPOINTPROTO._serialized_end=351
  _GEOGRAPHYLINESTRINGPROTO._serialized_start=353
  _GEOGRAPHYLINESTRINGPROTO._serialized_end=425
  _GEOGRAPHYPOLYGONPROTO._serialized_start=427
  _GEOGRAPHYPOLYGONPROTO._serialized_end=500
  _GEOGRAPHYRANGEENDPOINTPROTO._serialized_start=502
  _GEOGRAPHYRANGEENDPOINTPROTO._serialized_end=551
  _GEOGRAPHYPROTO._serialized_start=554
  _GEOGRAPHYPROTO._serialized_end=809
  _INT128PROTO._serialized_start=811
  _INT128PROTO._serialized_end=848
  _VALUE._serialized_start=851
  _VALUE._serialized_end=2265
  _CUSTOMVALUE._serialized_start=2267
  _CUSTOMVALUE._serialized_end=2311
  _FIELD._serialized_start=2313
  _FIELD._serialized_end=2364
  _OBJECTVALUE._serialized_start=2366
  _OBJECTVALUE._serialized_end=2411
  _ARRAYVALUE._serialized_start=2413
  _ARRAYVALUE._serialized_end=2456
  _NULLSVALUE._serialized_start=2458
  _NULLSVALUE._serialized_end=2487
  _INTARRAYVALUE._serialized_start=2489
  _INTARRAYVALUE._serialized_end=2555
  _FLOATARRAYVALUE._serialized_start=2557
  _FLOATARRAYVALUE._serialized_end=2625
  _BOOLARRAYVALUE._serialized_start=2627
  _BOOLARRAYVALUE._serialized_end=2694
  _STRINGARRAYVALUEDICTIONARY._serialized_start=2696
  _STRINGARRAYVALUEDICTIONARY._serialized_end=2756
  _STRINGARRAYVALUE._serialized_start=2758
  _STRINGARRAYVALUE._serialized_end=2884
  _LOCATORARRAYVALUE._serialized_start=2886
  _LOCATORARRAYVALUE._serialized_end=2979
  _TIMESTAMPARRAYVALUE._serialized_start=2981
  _TIMESTAMPARRAYVALUE._serialized_end=3053
  _DATETIMEARRAYVALUE._serialized_start=3055
  _DATETIMEARRAYVALUE._serialized_end=3150
  _DATEARRAYVALUE._serialized_start=3152
  _DATEARRAYVALUE._serialized_end=3239
  _TIMEARRAYVALUE._serialized_start=3241
  _TIMEARRAYVALUE._serialized_end=3328
  _MONTHINTERVALARRAYVALUE._serialized_start=3330
  _MONTHINTERVALARRAYVALUE._serialized_end=3406
  _MICROSECONDINTERVALARRAYVALUE._serialized_start=3408
  _MICROSECONDINTERVALARRAYVALUE._serialized_end=3490
  _INT128ARRAYVALUE._serialized_start=3492
  _INT128ARRAYVALUE._serialized_end=3583
  _TYPE._serialized_start=3586
  _TYPE._serialized_end=3982
  _TYPE_SCALARTYPE._serialized_start=3893
  _TYPE_SCALARTYPE._serialized_end=3968
  _KEYTYPE._serialized_start=3984
  _KEYTYPE._serialized_end=4035
  _OBJECTTYPE._serialized_start=4037
  _OBJECTTYPE._serialized_end=4079
  _ARRAYTYPE._serialized_start=4081
  _ARRAYTYPE._serialized_end=4121
  _CUSTOMTYPE._serialized_start=4123
  _CUSTOMTYPE._serialized_end=4149
  _BITSETPROTO._serialized_start=4151
  _BITSETPROTO._serialized_end=4180
# @@protoc_insertion_point(module_scope)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.avro_params import AvroParams  # noqa: F401,E501
from rockset.swagger_client.models.csv_params import CsvParams  # noqa: F401,E501
from rockset.swagger_client.models.xml_params import XmlParams  # noqa: F401,E501


class FormatParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'json': 'bool',
        'csv': 'CsvParams',
        'xml': 'XmlParams',
        'mysql_dms': 'bool',
        'postgres_dms': 'bool',
        'mssql_dms': 'bool',
        'oracle_dms': 'bool',
        'avro': 'AvroParams'
    }

    attribute_map = {
        'json': 'json',
        'csv': 'csv',
        'xml': 'xml',
        'mysql_dms': 'mysql_dms',
        'postgres_dms': 'postgres_dms',
        'mssql_dms': 'mssql_dms',
        'oracle_dms': 'oracle_dms',
        'avro': 'avro'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """FormatParams - a model defined in Swagger"""  # noqa: E501

        self._json = None
        self._csv = None
        self._xml = None
        self._mysql_dms = None
        self._postgres_dms = None
        self._mssql_dms = None
        self._oracle_dms = None
        self._avro = None
        self.discriminator = None

        self.json = kwargs.pop('json', None)
        self.csv = kwargs.pop('csv', None)
        self.xml = kwargs.pop('xml', None)
        self.mysql_dms = kwargs.pop('mysql_dms', None)
        self.postgres_dms = kwargs.pop('postgres_dms', None)
        self.mssql_dms = kwargs.pop('mssql_dms', None)
        self.oracle_dms = kwargs.pop('oracle_dms', None)
        self.avro = kwargs.pop('avro', None)

    @property
    def json(self):
        """Gets the json of this FormatParams.  # noqa: E501

        source data is in json format  # noqa: E501

        :return: The json of this FormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this FormatParams.

        source data is in json format  # noqa: E501

        :param json: The json of this FormatParams.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def csv(self):
        """Gets the csv of this FormatParams.  # noqa: E501


        :return: The csv of this FormatParams.  # noqa: E501
        :rtype: CsvParams
        """
        return self._csv

    @csv.setter
    def csv(self, csv):
        """Sets the csv of this FormatParams.


        :param csv: The csv of this FormatParams.  # noqa: E501
        :type: CsvParams
        """

        self._csv = csv

    @property
    def xml(self):
        """Gets the xml of this FormatParams.  # noqa: E501


        :return: The xml of this FormatParams.  # noqa: E501
        :rtype: XmlParams
        """
        return self._xml

    @xml.setter
    def xml(self, xml):
        """Sets the xml of this FormatParams.


        :param xml: The xml of this FormatParams.  # noqa: E501
        :type: XmlParams
        """

        self._xml = xml

    @property
    def mysql_dms(self):
        """Gets the mysql_dms of this FormatParams.  # noqa: E501


        :return: The mysql_dms of this FormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._mysql_dms

    @mysql_dms.setter
    def mysql_dms(self, mysql_dms):
        """Sets the mysql_dms of this FormatParams.


        :param mysql_dms: The mysql_dms of this FormatParams.  # noqa: E501
        :type: bool
        """

        self._mysql_dms = mysql_dms

    @property
    def postgres_dms(self):
        """Gets the postgres_dms of this FormatParams.  # noqa: E501


        :return: The postgres_dms of this FormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._postgres_dms

    @postgres_dms.setter
    def postgres_dms(self, postgres_dms):
        """Sets the postgres_dms of this FormatParams.


        :param postgres_dms: The postgres_dms of this FormatParams.  # noqa: E501
        :type: bool
        """

        self._postgres_dms = postgres_dms

    @property
    def mssql_dms(self):
        """Gets the mssql_dms of this FormatParams.  # noqa: E501


        :return: The mssql_dms of this FormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._mssql_dms

    @mssql_dms.setter
    def mssql_dms(self, mssql_dms):
        """Sets the mssql_dms of this FormatParams.


        :param mssql_dms: The mssql_dms of this FormatParams.  # noqa: E501
        :type: bool
        """

        self._mssql_dms = mssql_dms

    @property
    def oracle_dms(self):
        """Gets the oracle_dms of this FormatParams.  # noqa: E501


        :return: The oracle_dms of this FormatParams.  # noqa: E501
        :rtype: bool
        """
        return self._oracle_dms

    @oracle_dms.setter
    def oracle_dms(self, oracle_dms):
        """Sets the oracle_dms of this FormatParams.


        :param oracle_dms: The oracle_dms of this FormatParams.  # noqa: E501
        :type: bool
        """

        self._oracle_dms = oracle_dms

    @property
    def avro(self):
        """Gets the avro of this FormatParams.  # noqa: E501


        :return: The avro of this FormatParams.  # noqa: E501
        :rtype: AvroParams
        """
        return self._avro

    @avro.setter
    def avro(self, avro):
        """Sets the avro of this FormatParams.


        :param avro: The avro of this FormatParams.  # noqa: E501
        :type: AvroParams
        """

        self._avro = avro

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormatParams, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormatParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)
